APISchemaObject class

Represents a schema object in the OpenAPI specification.

Inheritance

Properties

additionalPropertyPolicy ↔ APISchemaAdditionalPropertyPolicy?
getter/setter pair
additionalPropertySchema ↔ APISchemaObject?
getter/setter pair
allOf ↔ List<APISchemaObject?>?
getter/setter pair
anyOf ↔ List<APISchemaObject?>?
getter/setter pair
castMap → Map<String, Cast>
no setter
defaultValue ↔ dynamic
getter/setter pair
deprecated ↔ bool?
getter/setter pair
description ↔ String?
getter/setter pair
discriminator ↔ APISchemaObject?
getter/setter pair
enumerated ↔ List?
The value of this keyword MUST be an array. This array SHOULD have at least one element. Elements in the array SHOULD be unique.
getter/setter pair
exclusiveMaximum ↔ bool?
The value of "exclusiveMaximum" MUST be a boolean, representing whether the limit in "maximum" is exclusive or not.
getter/setter pair
exclusiveMinimum ↔ bool?
The value of "exclusiveMinimum" MUST be a boolean, representing whether the limit in "minimum" is exclusive or not. An undefined value is the same as false. If "exclusiveMinimum" is true, then a numeric instance SHOULD NOT be equal to the value specified in "minimum". If "exclusiveMinimum" is false (or not specified), then a numeric instance MAY be equal to the value of "minimum".
getter/setter pair
extensions ↔ Map<String, dynamic>
getter/setter pairinherited
format ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isNullable ↔ bool?
getter/setter pair
isReadOnly ↔ bool?
getter/setter pair
isRequired ↔ List<String?>?
The value of this keyword MUST be an array. This array MUST have at least one element. Elements of this array MUST be strings, and MUST be unique.
getter/setter pair
isWriteOnly ↔ bool?
getter/setter pair
items ↔ APISchemaObject?
getter/setter pair
maximum ↔ num?
The value of "maximum" MUST be a number, representing an upper limit for a numeric instance.
getter/setter pair
maxItems ↔ int?
The value of this keyword MUST be an integer. This integer MUST be greater than, or equal to, 0.
getter/setter pair
maxLength ↔ int?
The value of this keyword MUST be a non-negative integer.
getter/setter pair
maxProperties ↔ int?
The value of this keyword MUST be an integer. This integer MUST be greater than, or equal to, 0.
getter/setter pair
minimum ↔ num?
The value of "minimum" MUST be a number, representing a lower limit for a numeric instance. If the instance is a number, then this keyword validates if "exclusiveMinimum" is true and instance is greater than the provided value, or else if the instance is greater than or exactly equal to the provided value.
getter/setter pair
minItems ↔ int?
The value of this keyword MUST be an integer. This integer MUST be greater than, or equal to, 0.
getter/setter pair
minLength ↔ int?
A string instance is valid against this keyword if its length is greater than, or equal to, the value of this keyword.
getter/setter pair
minProperties ↔ int?
The value of this keyword MUST be an integer. This integer MUST be greater than, or equal to, 0.
getter/setter pair
multipleOf ↔ num?
The value of "multipleOf" MUST be a number, strictly greater than 0. A numeric instance is only valid if division by this keyword's value results in an integer.
getter/setter pair
not ↔ APISchemaObject?
getter/setter pair
oneOf ↔ List<APISchemaObject?>?
getter/setter pair
pattern ↔ String?
The value of this keyword MUST be a string. This string SHOULD be a valid regular expression, according to the ECMA 262 regular expression dialect.
getter/setter pair
properties ↔ Map<String, APISchemaObject?>?
getter/setter pair
propertyName ↔ String?
getter/setter pair
referenceURI ↔ Uri?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
A title for the object.
getter/setter pair
type ↔ APIType?
getter/setter pair
uniqueItems ↔ bool?
The value of this keyword MUST be a boolean.
getter/setter pair

Methods

decode(KeyedArchive object) → void
override
encode(KeyedArchive object) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited